/*
 * Quimeleon - a themeable quiz engine
 * Copyright (C) 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "plugin_timer.h"

#include <iostream>
#include <numeric>
#include <sstream>

#include "item_pixbuf.h"




namespace quimeleon_plugin {





const char* PluginTimer::_name = "Timer";




PluginTimer::PluginTimer(quimeleon::Control* control)
	: quimeleon::Plugin(control),
	  _cnt(60)
{
	use_area("timer");
}




void
PluginTimer::activate(const Glib::ustring& arg)
{
	quimeleon::ItemArea* item_area = get_area("timer");

	if (item_area) {
		_item_text
			= dynamic_cast<quimeleon::ItemLabel*>(
				item_area->find_id("timertext"));

		if (_item_text) {
			Glib::ustring text;
			if (! arg.empty()) {
				text = arg;
			} else {
				text = _item_text->content();
			}
			_item_text->set_text(text);
			std::istringstream istr(text);
			istr >> _cnt;
			item_area->show();

			_timer_connection = Glib::signal_timeout().connect(
				sigc::mem_fun(*this, &PluginTimer::count), 1000);
		}
	} else {
		std::cerr << "Cannot find area 'timer'\n";
	}
}



void
PluginTimer::deactivate()
{
	quimeleon::ItemArea* item_area = get_area("timer");

	if (item_area) {
		item_area->hide();
		if (_timer_connection) {
			_timer_connection.disconnect();
		}
		_cnt = 0;
	} else {
		std::cerr << "Cannot find area 'timer'\n";
	}
}



bool
PluginTimer::count()
{
	if (_cnt > 0) {
		_cnt--;
		std::ostringstream ostr;
		ostr << _cnt;
		_item_text->set_text(ostr.str());

		get_area("timer")->redraw();

		return true;
	} else {
		return false;
	}
}





} // end namespace quimeleon_plugin
