/*
 * Action - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "action.h"
#include "plugin.h"

#include "gettext.h"




namespace quimeleon {





// ISO C++ forbids casting between pointer-to-function and
// pointer-to-object
// (and so does C, dlsym() is not ISO-C++ either)
union plugin_conversion_t {
	plugin_t plugin_function;
	void* plugin_object;
};




Action::Action(Configuration* configuration, Control* control)
{
	initialize(configuration, control);
}




void
Action::initialize(Configuration* configuration, Control* control)
{
	const std::vector<std::string>& plugins = configuration->plugins();
	for (std::vector<std::string>::const_iterator i = plugins.begin();
	     i < plugins.end(); i++) {
		try {
			if (find(*i) != end()) {
				continue;
			}
			Glib::Module module(configuration->find_file(*i + ".so"));

			if (module) {
				plugin_conversion_t func;
				func.plugin_object = 0;
				bool found
					= module.get_symbol("quimeleon_plugin", func.plugin_object);
				if (found) {
					plugin_t get_plugin = func.plugin_function;

					try {
						insert(std::pair<std::string, Plugin*>(
							*i, get_plugin(control)));

						module.make_resident();
					} catch (const Plugin::InitFailed& e) {
						std::cerr << "plugin " << *i << ": "
							<< e.what() << '\n';
					}
				} else {
					std::cerr << _("Unable to initialize plugin")
						<< ' ' << *i << '\n';
				}
			} else {
				std::cerr << _("Unable to load plugin")
					<< ' ' << *i << ": "
					<< module.get_last_error() << '\n';
			}
		} catch (const FileNotFound& e) {
			std::cerr << _("Unable to load plugin") << ": " << e.what() << '\n';
		}
	}
}



void
Action::reinitialize(Configuration* configuration, Control* control)
{
	clear();
	initialize(configuration, control);
}





} // end namespace quimeleon
