/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005, 2006  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_CONFIGURATION_H
#define QUIMELEON_CONFIGURATION_H

#include <istream>

#include <sys/types.h>
#include <sys/stat.h>

#include "audio.h"
#include "error.h"
#include "item_top.h"
#include "keys.h"





namespace quimeleon {





std::string absolute_path(const std::string& filename);



class Plugin;



class Configuration
{
public:
	Configuration();
	Configuration(const Configuration& configuration);

	~Configuration();

	void operator=(const Configuration& configuration);

	void read_options();
	void save_style_and_trivia();
	void save_options();

	void reset_style();

	inline ItemTop*& item_top() throw() { return _item_top; }
	inline Audio*& audio() throw() { return _audio; }
	inline const Keys& keys() const throw() { return _keys; }
	inline Keys& keys() throw() { return _keys; }
	std::vector<std::string> plugins();
	inline const std::vector<Glib::ustring>& actions_autonomous() const throw()
	{
		return _action_autonomouss;
	}
	inline const std::vector<Glib::ustring>&
	action_args_autonomous() const throw()
	{
		return _action_arg_autonomouss;
	}

	std::string find_file(const std::string& filename) const;

	void add_data_dir(std::string dirname);
	inline void set_trivia_file(const std::string& filename)
	{
		_trivia_file = filename;
	}
	inline void set_style_file(const std::string& filename)
	{
		_style_file = filename;
	}
	inline void set_style_name(const std::string& style_name)
	{
		_style_name = style_name;
	}

	inline const std::vector<std::string>& data_dirs()
	{
		return _data_dirs;
	}
	inline void data_dirs_clear()
	{
		_data_dirs.resize(_global_data_dirs_size);
	}
	inline std::vector<std::string>::size_type
	global_data_dirs_size() const throw()
	{
		return _global_data_dirs_size;
	}
	
	inline std::string trivia_file() const
	{
		return find_file(_trivia_file);
	}
	inline std::string trivia_file_name() const throw()
	{
		return _trivia_file;
	}
	inline std::string style_file() const
	{
		return find_file(_style_file);
	}
	inline std::string style_file_name() const throw()
	{
		return _style_file;
	}
	inline std::string style_name() const throw()
	{
		return _style_name;
	}

	inline void set_max_level_cnt(unsigned int max_level_cnt) throw()
	{
		_max_level_cnt = max_level_cnt;
	}
	inline unsigned int max_level_cnt() const throw() { return _max_level_cnt; }

	inline unsigned int add_action_autonomous(const Glib::ustring& action,
		const Glib::ustring& arg)
	{
		_action_autonomouss.push_back(action);
		_action_arg_autonomouss.push_back(arg);

		return _action_autonomouss.size() - 1;
	}

	inline void set_do_buffer(bool do_buffer) throw()
	{
		_do_buffer = do_buffer;
	}
	inline bool do_buffer() const throw() { return _do_buffer; }

	inline void set_fullscreen(bool fullscreen) throw()
	{
		_fullscreen = fullscreen;
	}
	inline bool fullscreen() const throw() { return _fullscreen; }

	inline void set_do_show_hint(bool do_show_hint) throw()
	{
		_do_show_hint = do_show_hint;
	}
	inline bool do_show_hint() const throw() { return _do_show_hint; }


	const std::string& lang() const throw() { return _lang; }

private:
	void read_datadir_file(const std::string& filename);
	bool read_options_file(const std::string& filename);


private:
	std::string _lang;

	ItemTop* _item_top;
	Audio* _audio;
	Keys _keys;

	std::vector<std::string> _data_dirs;
	std::string _trivia_file;
	std::string _style_file;
	std::string _style_name;

	unsigned int _max_level_cnt;

	std::vector<Glib::ustring> _action_autonomouss;
	std::vector<Glib::ustring> _action_arg_autonomouss;

	bool _do_buffer;
	bool _fullscreen;
	bool _do_show_hint;


	std::vector<std::string>::size_type _global_data_dirs_size;
	std::string _global_trivia_file;
	std::string _global_style_file;
	std::string _global_style_name;
	bool _global_do_buffer;
	bool _global_fullscreen;
	bool _global_do_show_hint;

};





} // end namespace quimeleon




#endif
