/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005, 2006  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_CONTROL_H
#define QUIMELEON_CONTROL_H

#include <map>

#include <gtkmm/window.h>

#include "configuration.h"
#include "item_area.h"
#include "trivias.h"




namespace quimeleon {





enum gamestate_t {
	STATE_black,
	STATE_intro,
	STATE_start,
	STATE_question,
	STATE_answer,
	STATE_show_answer,
	STATE_game_lost,
	STATE_end
};


enum gamesubstate_t {
	SUBSTATE_normal,
	SUBSTATE_overlay_prepared,
	SUBSTATE_overlay
};




class Control
{
public:
	Control(Configuration* configuration, const Trivias& trivias);

	void set_trivia(const Trivias& trivias);
	void on_item_top_changed();

	
	void set_gamestate(gamestate_t gamestate) throw();
	gamestate_t gamestate() throw();

	ItemArea* get_area(const Glib::ustring& id);

	unsigned int questions_cnt() const;
	unsigned int question_n() const throw();

	bool set_question(unsigned int n);
	bool prev_question();
	bool next_question();
	void reset_question();


	unsigned int answers_cnt();
	unsigned int correct();

	bool answer_all_correct();
	bool answer_correct_correct();

	bool answer_normal(unsigned int n);
	bool answer_selected(unsigned int n);
	bool answer_correct(unsigned int n);
	bool answer_wrong(unsigned int n);
	bool answer_corrected(unsigned int n);
	bool answer_insensitive(unsigned int n);

	void play_answer_audio(Audio::audio_t audio);

	bool prev_level();
	bool next_level();
	void reset_level();

	void action_activate(Plugin* plugin, const Glib::ustring& arg);
	void action_deactivate();
	void free_canvas();

	void next_status(unsigned int number);
	void prev_status(unsigned int number);
	void set_status(unsigned int number, unsigned int n);
	void reset_status();

	bool substate_next();

private:
	void image_overlay_prepare(const Glib::ustring& image);
	void image_overlay(const Glib::ustring& image);
	void image_shrink();

private:
	Configuration* _configuration;

	Trivias _trivias;
	Trivias::size_type _level_cnt;

	gamestate_t _state;
	gamesubstate_t _substate;
	unsigned int _question_n;
	unsigned int _level_n;

	Plugin* _action_active;
	ItemArea* _area_output_overlay;
	ItemArea* _area_output;

	Glib::ustring _image_overlaid;
	unsigned int _correct_pos;
};





} // end namespace quimeleon




#endif
