/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2003, 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "error.h"

#include "gettext.h"




namespace quimeleon {





FileError::FileError(const std::string& str)
	: Exception(std::string(_("file error")) + ": " + str) {}


FileNotFound::FileNotFound(const std::string& str)
	: FileError(std::string(_("not found")) + ": " + str) {}


ReadError::ReadError(const std::string& str)
	: FileError(std::string(_("read error")) + ": " + str) {}


WriteError::WriteError(const std::string& str)
	: FileError(std::string(_("write error")) + ": " + str) {}


CreateError::CreateError(const std::string& str)
	: FileError(std::string(_("cannot create")) + ": " + str) {}


ParserError::ParserError(const std::string& str)
	: Exception(str) {}


ParserTriviaError::ParserTriviaError(const std::string& str)
	: ParserError(std::string(_("trivia parser error")) + ": " + str) {}


ParserStyleError::ParserStyleError(const std::string& str)
	: ParserError(std::string(_("style parser error")) + ": " + str) {}


InvalidId::InvalidId(const std::string& str)
	: ParserStyleError(std::string(_("invalid id")) + ": " + str) {}


MissingItem::MissingItem(const std::string& str)
	: ParserStyleError(std::string(_("missing item")) + ": " + str) {}


AttributeEmpty::AttributeEmpty(const std::string& str)
	: ParserStyleError(std::string(_("empty attribute")) + ": " + str) {}


AttributeInvalid::AttributeInvalid(const std::string& str)
	: ParserStyleError(std::string(_("invalid attribute")) + ": " + str) {}


LayoutError::LayoutError(const std::string& str)
	: Exception(std::string(_("layout error")) + ": " + str) {}


ProgramError::ProgramError(const std::string& str)
	: Exception(std::string(_("program error")) + ": " + str) {}





} // end namespace quimeleon
