/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_ITEM_ANSWER_H
#define QUIMELEON_ITEM_ANSWER_H

#include "error.h"
#include "item_label.h"
#include "item_pixmap.h"
#include "item_multi.h"




namespace quimeleon {





class ItemAnswer : public ItemMulti
{
public:
	ItemAnswer(const Item* parent = 0,
		const Glib::ustring& id = "", item_type_t type = T_rect,
		int number = -1);

	void complete_attributes();

	void set_text_and_image(const Glib::ustring& text,
		const Glib::ustring& image,
		bool compose = true);
	void mark_state(state_t state, bool do_compose = true);

	const std::vector<ItemAnswer*>& answers() const;

	inline void set_is_used(bool is_used) throw()
	{
		if (is_used != _is_used) {
			_is_used = is_used;
		}
	}


protected:
	void compose_pixbuf();


private:
	Glib::ustring _text;
	Glib::ustring _image;

	ItemLabel* _text_item;
	ItemPixmap* _image_item;
	answer_type_t _answer_type;

	mutable bool _is_used;
};





} // end namespace quimeleon




#endif
