/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_ITEM_LABEL_H
#define QUIMELEON_ITEM_LABEL_H

#include "item.h"




namespace quimeleon {





enum alignment_t {
	align_left,
	align_center,
	align_right,
	align_justify
};





class ItemLabel : public Item
{
public:
	ItemLabel(const Item* parent = 0,
		const Glib::ustring& id = "", item_type_t type = T_label);

	void complete_attributes();

	inline void set_font_normal(const Glib::ustring& font)
	{
		_font_normal = font;
	}
	inline void set_font_selected(const Glib::ustring& font)
	{
		_font_selected = font;
	}
	inline void set_font_active(const Glib::ustring& font)
	{
		_font_active = font;
	}
	inline void set_font_prelight(const Glib::ustring& font)
	{
		_font_prelight = font;
	}
	inline void set_font_inactive(const Glib::ustring& font)
	{
		_font_inactive = font;
	}
	inline void set_font_insensitive(const Glib::ustring& font)
	{
		_font_insensitive = font;
	}


	void set_text(const Glib::ustring& text)
	{
		_text = text;
	}

	inline void set_alignment(alignment_t alignment) throw()
	{
		_alignment = alignment;
	}
	inline void set_parse(bool parse) throw() { _parse = parse; }

	void set_parse_arg(int label_number);


	const Glib::ustring& font() const throw();
	bool parse() const throw() { return _parse; }
	const Glib::ustring& text() const throw();


protected:
	void compose_pixbuf();


private:
	Glib::ustring _text;
	Glib::ustring _font_normal;
	Glib::ustring _font_selected;
	Glib::ustring _font_active;
	Glib::ustring _font_prelight;
	Glib::ustring _font_inactive;
	Glib::ustring _font_insensitive;

	alignment_t _alignment;
	bool _parse;
	Glib::ustring _text_generated;
};





} // end namespace quimeleon




#endif
