/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "item_level.h"




namespace quimeleon {





ItemLevel::ItemLevel(Item* parent,
	const Glib::ustring& id, item_type_t type, int number)
	: ItemMulti(parent, id, type, number),
	  _parent(parent)
{
}




void
ItemLevel::complete_attributes()
{
	find_parsed_labels(children());

	ItemRect::complete_attributes();
}



void
ItemLevel::find_parsed_labels(const std::vector<std::vector<Item*> >& children)
{
	for (std::vector<std::vector<Item*> >::const_iterator i = children.begin();
	     i < children.end(); i++) {
		for (std::vector<Item*>::const_iterator j = i->begin();
		     j < i->end(); j++) {
			if (ItemLabel* item_label = dynamic_cast<ItemLabel*>(*j)) {
				if (item_label->parse()) {
					_parsed_labels.push_back(item_label);
				}
			}
			find_parsed_labels((*j)->children());
		}
	}
}



void
ItemLevel::set_label_number(int label_number)
{
	for (std::vector<ItemLabel*>::iterator i = _parsed_labels.begin();
	     i < _parsed_labels.end(); i++) {
		(*i)->set_parse_arg(label_number);
	}
}



const std::vector<ItemLevel*>&
ItemLevel::levels() const
{
	if (_levels.empty()) {
		_levels.push_back(const_cast<ItemLevel*>(this));
	}

	return _levels;
}



void
ItemLevel::mark_state(state_t new_state, bool do_compose)
{
	if (new_state == state()) {
		return;
	}

	set_state_rec(new_state);

	if (   do_compose
	    && restore_pixbuf()) {
		ItemRect::compose_pixbuf();

		signal_expose();
	}
}






} // end namespace quimeleon
