/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_ITEM_PIXBUF_H
#define QUIMELEON_ITEM_PIXBUF_H

#include "error.h"


#include "item_area.h"



namespace quimeleon {




class ItemPixbuf : public ItemArea
{
public:
	ItemPixbuf(const Item* parent = 0,
		const Glib::ustring& id = "", item_type_t type = T_area);

	void set_parent_dimensions(
		int parent_x, int parent_y, int parent_w, int parent_h,
		int crop_x, int crop_y, int crop_w, int crop_h);

	Glib::RefPtr<Gdk::Pixbuf>& get_pixbuf();
	Glib::RefPtr<Gdk::Drawable>& drawable();
	void put_drawable();
	Glib::RefPtr<Gdk::GC>& get_gc() throw();

	const Gdk::Color color_normal();
	const Gdk::Color color_selected();
	const Gdk::Color color_active();
	const Gdk::Color color_prelight();
	const Gdk::Color color_inactive();
	const Gdk::Color color_insensitive();

	sigc::signal<void, const Glib::ustring&>& signal_draw_pixbuf()
	{
		return _signal_draw_pixbuf;
	}

protected:
	void compose_pixbuf();

private:
	Glib::RefPtr<Gdk::Pixbuf> _sub_pixbuf;

	Glib::RefPtr<Gdk::Drawable> _drawable;
	Glib::RefPtr<Gdk::GC> _gc;

	sigc::signal<void, const Glib::ustring&> _signal_draw_pixbuf;
};





} // end namespace quimeleon




#endif
