/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_ITEM_TOP_H
#define QUIMELEON_ITEM_TOP_H

#include "trivia.h"

#include "item.h"
#include "item_area.h"




namespace quimeleon {





enum mode_t {
	mode_black,
	mode_intro,
	mode_blank,
	mode_trivia,
	mode_outro_win,
	mode_outro_lose
};


enum group_t {
	group_trivia,
	group_output,
	group_intro,
	group_outro_win,
	group_outro_lose
};




class ItemTop : public Item
{
public:
	ItemTop();
	~ItemTop();

	void reset();


	void parse_sequence(bool sequence, group_t group);
	void add_child(Item* child, group_t group);
	void add_pause(int seconds, group_t group);


	void draw(int x = 0, int y = 0, int w = -1, int h = -1,
		bool do_expose = false);

	void set_parent_dimensions(int x, int y, int width, int height);

	unsigned int set_question(const Glib::ustring& question,
		const std::vector<answer_t>& answers,
		unsigned int correct,
		bool& alternative_changed);
	unsigned int set_level_cnt(unsigned int level_cnt);

	int set_mode(mode_t mode);
	int set_sequence_pos(unsigned int n);

	inline unsigned int sequence_pos() const throw() { return _sequence_pos; }


	void mark_state_level(unsigned int level, state_t state);

	ItemArea* get_area(const Glib::ustring& id = "default");


protected:
	void compose_pixbuf();


private:
	mode_t _mode;

	std::vector<std::vector<Item*> > _children_intro;
	std::vector<std::vector<Item*> > _children_outro_win;
	std::vector<std::vector<Item*> > _children_outro_lose;
	std::vector<int> _pauses_intro;
	std::vector<int> _pauses_outro_win;
	std::vector<int> _pauses_outro_lose;

	unsigned int _level_cnt;

	bool _parse_sequence;
	unsigned int _sequence_pos;
};





} // end namespace quimeleon




#endif
