/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include <gdk/gdkkeysyms.h>

#include "keys.h"



namespace quimeleon {





Keys::Keys() throw()
{
}




command_t
Keys::command(const GdkEventKey& key) const throw()
{
	std::map<guint, command_t>::const_iterator i
		= _keyval_commands.find(key.keyval);
	if (i != _keyval_commands.end()) {
		return i->second;
	}

	switch (key.keyval) {
	case GDK_Left:
		return command_prev_question;
	case GDK_Right:
		return command_next_question;
	case GDK_Down:
		return command_prev_level;
	case GDK_Up:
		return command_next_level;
	case GDK_F11:
		return command_toggle_fullscreen;
	case GDK_Escape:
		return command_quit;
	case GDK_Return:
		return command_continue;
	case GDK_KP_Add:
		return command_next_status_begin;
	case GDK_KP_Subtract:
		return command_prev_status_begin;
	case GDK_KP_1:
		return command_set_status_begin;
	case GDK_KP_2:
		return command_t(command_set_status_begin + 1);
	case GDK_KP_3:
		return command_t(command_set_status_begin + 2);
	case GDK_KP_4:
		return command_t(command_set_status_begin + 3);
	case GDK_KP_5:
		return command_t(command_set_status_begin + 4);
	case GDK_KP_6:
		return command_t(command_set_status_begin + 5);
	case GDK_KP_7:
		return command_t(command_set_status_begin + 6);
	case GDK_KP_8:
		return command_t(command_set_status_begin + 7);
	case GDK_KP_9:
		return command_t(command_set_status_begin + 8);
	case GDK_KP_0:
		return command_t(command_set_status_begin + 9);
	case ' ':
		return command_continue_benevolent;
	case 'a':
		return command_select_answer_begin;
	case 'b':
		return command_t(command_select_answer_begin + 1);
	case 'c':
		return command_t(command_select_answer_begin + 2);
	case 'd':
		return command_t(command_select_answer_begin + 3);
	case 'e':
		return command_t(command_select_answer_begin + 4);
	case 'f':
		return command_t(command_select_answer_begin + 5);
	case 'g':
		return command_t(command_select_answer_begin + 6);
	case 'h':
		return command_t(command_select_answer_begin + 7);
	case 'i':
		return command_t(command_select_answer_begin + 8);
	case 'j':
		return command_t(command_select_answer_begin + 9);
	case 'k':
		return command_t(command_select_answer_begin + 10);
	case 'l':
		return command_t(command_select_answer_begin + 11);
	case 'm':
		return command_t(command_select_answer_begin + 12);
	case 'n':
		return command_t(command_select_answer_begin + 13);
	case 'o':
		return command_t(command_select_answer_begin + 14);
	case 'p':
		return command_t(command_select_answer_begin + 15);
	case 'q':
		return command_t(command_select_answer_begin + 16);
	case 'r':
		return command_t(command_select_answer_begin + 17);
	case 's':
		return command_t(command_select_answer_begin + 18);
	case 't':
		return command_t(command_select_answer_begin + 19);
	case 'u':
		return command_t(command_select_answer_begin + 20);
	case 'v':
		return command_t(command_select_answer_begin + 21);
	case 'w':
		return command_t(command_select_answer_begin + 22);
	case 'x':
		return command_t(command_select_answer_begin + 23);
	case 'y':
		return command_t(command_select_answer_begin + 24);
	case 'z':
		return command_t(command_select_answer_begin + 25);
	case 'A':
		return command_deselect_answer_begin;
	case 'B':
		return command_t(command_deselect_answer_begin + 1);
	case 'C':
		return command_t(command_deselect_answer_begin + 2);
	case 'D':
		return command_t(command_deselect_answer_begin + 3);
	case 'E':
		return command_t(command_deselect_answer_begin + 4);
	case 'F':
		return command_t(command_deselect_answer_begin + 5);
	case 'G':
		return command_t(command_deselect_answer_begin + 6);
	case 'H':
		return command_t(command_deselect_answer_begin + 7);
	case 'I':
		return command_t(command_deselect_answer_begin + 8);
	case 'J':
		return command_t(command_deselect_answer_begin + 9);
	case 'K':
		return command_t(command_deselect_answer_begin + 10);
	case 'L':
		return command_t(command_deselect_answer_begin + 11);
	case 'M':
		return command_t(command_deselect_answer_begin + 12);
	case 'N':
		return command_t(command_deselect_answer_begin + 13);
	case 'O':
		return command_t(command_deselect_answer_begin + 14);
	case 'P':
		return command_t(command_deselect_answer_begin + 15);
	case 'Q':
		return command_t(command_deselect_answer_begin + 16);
	case 'R':
		return command_t(command_deselect_answer_begin + 17);
	case 'S':
		return command_t(command_deselect_answer_begin + 18);
	case 'T':
		return command_t(command_deselect_answer_begin + 19);
	case 'U':
		return command_t(command_deselect_answer_begin + 20);
	case 'V':
		return command_t(command_deselect_answer_begin + 21);
	case 'W':
		return command_t(command_deselect_answer_begin + 22);
	case 'X':
		return command_t(command_deselect_answer_begin + 23);
	case 'Y':
		return command_t(command_deselect_answer_begin + 24);
	case 'Z':
		return command_t(command_deselect_answer_begin + 25);
	case '1':
		return command_select_action_begin;
	case '2':
		return command_t(command_select_action_begin + 1);
	case '3':
		return command_t(command_select_action_begin + 2);
	case '4':
		return command_t(command_select_action_begin + 3);
	case '5':
		return command_t(command_select_action_begin + 4);
	case '6':
		return command_t(command_select_action_begin + 5);
	case '7':
		return command_t(command_select_action_begin + 6);
	case '8':
		return command_t(command_select_action_begin + 7);
	case '9':
		return command_t(command_select_action_begin + 8);
	case '0':
		return command_t(command_select_action_begin + 9);
	default:
		return command_undefined;
	}
}





} // end namespace quimeleon
