/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2006  Aike Reyer <aike@users.sourceforge.net>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_LIST_VIEW_TEXT_H
#define QUIMELEON_LIST_VIEW_TEXT_H

#include <gtkmm/treeview.h>
#include <gtkmm/liststore.h>




namespace quimeleon {





class ListViewText : public Gtk::TreeView
{
public:
	ListViewText();

	void append_disabled_text(const Glib::ustring& text);
	void append_text(const Glib::ustring& text);
	void insert_text(const Glib::ustring& text);
	void set_selected_text(const Glib::ustring& text);

	void erase_selected();
	void move_selected_up();
	void move_selected_down();

	const Glib::ustring get_selected_text();

	Glib::ustring get_text(int row);

protected:
	void on_selection_changed();
	bool select_function(const Glib::RefPtr<Gtk::TreeModel>& model,
		const Gtk::TreeModel::Path& path, bool path_currently_selected);


public:
	struct ColumnRecord : public Gtk::TreeModel::ColumnRecord
	{
		ColumnRecord()
		{
			add(_text);
			add(_is_marked);
			add(_is_editable);
		}

		Gtk::TreeModelColumn<Glib::ustring> _text;
		Gtk::TreeModelColumn<bool> _is_marked;
		Gtk::TreeModelColumn<bool> _is_editable;
	};

	const ColumnRecord& column_record() const throw() { return _column_record; }

	typedef sigc::signal<void, bool> edit_enabled_t;
	inline edit_enabled_t& signal_edit_enabled() throw()
	{
		return _signal_edit_enabled;
	}


private:
	ColumnRecord _column_record;

	Glib::RefPtr<Gtk::ListStore> _tree_model;

	edit_enabled_t _signal_edit_enabled;

	bool _is_edit_enabled;
};





} // end namespace quimeleon




#endif
