/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "plugin.h"

#include "item_pixbuf.h"

#include "gettext.h"




namespace quimeleon {





Plugin::Plugin(Control* control)
	: _control(control)
{
}



Plugin::~Plugin()
{
}




void
Plugin::deactivate()
{
}



void
Plugin::free_canvas()
{
	deactivate();
}



void
Plugin::draw(const Glib::ustring& id)
{
}



void
Plugin::use_area(const Glib::ustring& id)
{
	ItemArea* item_area = dynamic_cast<ItemArea*>(control()->get_area(id));

	if (item_area) {
		_areas.insert(std::pair<const Glib::ustring, ItemArea*>(id, item_area));
	} else {
		std::cerr << _("No such area") << ": " << id << '\n';
	}
}


void
Plugin::use_pixbuf(const Glib::ustring& id)
{
	bool is_found = false;

	for (std::map<const Glib::ustring, ItemArea*>::iterator i = _areas.begin();
	     i != _areas.end(); i++) {
		ItemPixbuf* item_pixbuf
			= dynamic_cast<ItemPixbuf*>(i->second->find_id(id));

		if (item_pixbuf) {
			item_pixbuf->signal_draw_pixbuf().connect(
				sigc::mem_fun(*this, &Plugin::draw));
			_pixbufs.insert(
				std::pair<const Glib::ustring, ItemPixbuf*>(id, item_pixbuf));
			is_found = true;
		}
	}

	if (! is_found) {
		std::cerr << _("No such pixbuf") << ": " << id << '\n';
	}
}



ItemArea*
Plugin::get_area(const Glib::ustring& id)
{
	std::map<const Glib::ustring, ItemArea*>::iterator i = _areas.find(id);

	if (i == _areas.end()) {
		return 0;
	} else {
		return i->second;
	}
}



ItemPixbuf*
Plugin::get_pixbuf(const Glib::ustring& id)
{
	std::map<const Glib::ustring, ItemPixbuf*>::iterator i
		= _pixbufs.find(id);

	if (i == _pixbufs.end()) {
		return 0;
	} else {
		return i->second;
	}
}





} // end namespace quimeleon
