/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_PLUGIN_H
#define QUIMELEON_PLUGIN_H

#include "control.h"
#include "error.h"




namespace quimeleon {





class Plugin
{
public:
	class InitFailed : public Exception
	{
	public:
		InitFailed(const std::string str)
			: Exception(str) {}
	};

	Plugin(Control* control);
	virtual ~Plugin();

	virtual const char* name() const  = 0;
	virtual void activate(const Glib::ustring& arg) = 0;
	virtual void deactivate();

	virtual void free_canvas();

	virtual void draw(const Glib::ustring& id);

protected:
	void use_area(const Glib::ustring& id);
	void use_pixbuf(const Glib::ustring& id);

	inline Control* control() throw() { return _control; }
	ItemArea* get_area(const Glib::ustring& id);
	ItemPixbuf* get_pixbuf(const Glib::ustring& id);


private:
	Control* _control;

	std::map<const Glib::ustring, ItemArea*> _areas;
	std::map<const Glib::ustring, ItemPixbuf*> _pixbufs;
};




typedef Plugin* (*plugin_t)(Control* control);





} // end namespace quimeleon




#endif
