/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_QUIMELEON_H
#define QUIMELEON_QUIMELEON_H

#include <map>

#include <gtkmm/box.h>
#include <gtkmm/window.h>

#include "action.h"
#include "configuration.h"
#include "control.h"
#include "display.h"
#include "keys.h"
#include "plugin.h"
#include "trivia.h"
#include "dialogs.h"
#include "ui_manager.h"




namespace quimeleon {





class Quimeleon : public Gtk::Window
{
public:
	Quimeleon(Configuration* configuration, const Trivias& trivias);


protected:
	bool on_key_press_event(GdkEventKey* key);
	bool on_window_state_event(GdkEventWindowState* event) throw();
	void on_show();

	bool auto_continue();


	bool start_mouse_watch(GdkEventCrossing* event);
	bool stop_mouse_watch(GdkEventCrossing* event);
	bool timer_mouse();
	bool on_mouse_motion_notify_event(GdkEventMotion* event);

private:
	Configuration* _configuration;

	Control _control;
	Action _plugins;

	bool _is_fullscreen;
	sigc::connection _timer_connection;

	Gtk::VBox _vbox;
	Display _display;
	Glib::RefPtr<UIManager> _ui_manager;
	Gtk::Widget* _menu;
	Gtk::Widget* _toolbar;

	Dialogs _dialogs;


	sigc::connection _connection_mouse;
	int _mouse_x;
	int _mouse_y;
};





} // end namespace quimeleon




#endif
