/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2003, 2005, 2006  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include <fstream>
#include <sstream>

#include <cctype>

#include "trivia.h"
#include "configuration.h"

#include <iostream>

#include "gettext.h"




namespace quimeleon {





Trivia::Trivia() throw()
{
}



Trivia::Trivia(const Glib::ustring& question,
               const std::vector<answer_t>& answers,
               const std::vector<Glib::ustring>::size_type& correct,
               const Glib::ustring& question_audio,
               const Glib::ustring& answer_audio,
			   const Glib::ustring& question_image,
			   const Glib::ustring& answer_image)
	: _question(question),
	  _answers(answers),
	  _correct(correct),
	  _question_audio(question_audio),
	  _answer_audio(answer_audio),
	  _question_image(question_image),
	  _answer_image(answer_image)
{
}




Trivias
Trivia::read_trivia_file(const char* filename,
	const Configuration& configuration)
{
	std::ifstream ifile(filename);
	if (! ifile) {
		throw ReadError(filename);
	}
	std::string line;

	Trivias re;

	Glib::ustring question;
	std::vector<answer_t> answers;
	Glib::ustring question_audio;
	Glib::ustring answer_audio;
	Glib::ustring question_image;
	Glib::ustring answer_image;
	int correct = -1;

	while (! ifile.eof()) {
		std::getline(ifile, line);
		Glib::ustring::size_type pos = line.find('=');
		if (pos != Glib::ustring::npos) {
			Glib::ustring key = line.substr(0, pos);
			Glib::ustring value = line.substr(pos + 1);
			try {
				switch (key[0]) {
				case 'q':	// q, qaudio, qimg
					if (key.length() > 1) {
						switch (key[1]) {
						case 'a':	// qaudio
							question_audio = configuration.find_file(value);
							break;
						default:	// qimg
							question_image = configuration.find_file(value);
							break;
						}
					} else {
						question = value;
					}
					break;
				case 'a':	// a[0-9]+, a, aaudio
					if (key.length() > 1) {
						switch (key[1]) {
						case 'a':	// aaudio
							answer_audio = configuration.find_file(value);
							break;
						case 'i':	// aimg
							answer_image = configuration.find_file(value);
							break;
						default:
							if (std::isdigit(key[1])) {
								Glib::ustring::size_type i = 
									key.find_first_not_of("0123456789", 2);
								std::istringstream ist(key.substr(1, i));
								unsigned int n;
								ist >> n;

								if (n >= answers.size()) {
									answers.resize(n + 1);
								}
								if (i == Glib::ustring::npos) {
									answers[n].text = value;
								} else {
									answers[n].image
										= configuration.find_file(value);
								}
							}
						}
					} else {
						std::istringstream ist(value);
						int n;
						ist >> n;

						correct = n;
					}
					break;
				case 'm': {	// max levels
					unsigned int max_level_cnt;
					std::istringstream ist(value);
					ist >> max_level_cnt;
					if (max_level_cnt > 0) {
						re.set_max_level_cnt(max_level_cnt);
					} else {
						std::cerr << _("invalid value for key: ")
							<< key << '=' << value << '\n';
					}
				}
				}
			} catch (const FileNotFound& e) {
				std::cerr << key << ": " << e.what() << '\n';
			}
		} else if (   ! line.empty()
		           && line[0] == '[') {
			if (   correct >= 0
			    && std::vector<answer_t>::size_type(correct) < answers.size()) {
				std::vector<answer_t> in_answers;
				for (std::vector<answer_t>::const_iterator i = answers.begin();
				     i != answers.end(); i++) {
					if (! (i->text.empty() && i->image.empty())) {
						in_answers.push_back(*i);
					} else if (std::vector<answer_t>::size_type(correct)
					           	>= in_answers.size()) {
						correct--;
					}
				}

				if (! in_answers.empty()) {
					re.push_back(Trivia(question, in_answers, correct,
						question_audio, answer_audio,
						question_image, answer_image));
				}

			}

			question = "";
			question_audio = "";
			answer_audio = "";
			question_image = "";
			answer_image = "";
			answers.clear();
			correct = -1;
		}
	}

	if (correct >= 0 && correct < int(answers.size())) {
		std::vector<answer_t> in_answers;
		for (std::vector<answer_t>::const_iterator i = answers.begin();
		     i != answers.end(); i++) {
			if (! (i->text.empty() && i->image.empty())) {
				in_answers.push_back(*i);
			} else if (correct >= int(in_answers.size())) {
				correct--;
			}
		}

		if (! in_answers.empty()) {
			re.push_back(Trivia(question, in_answers, correct,
				question_audio, answer_audio,
				question_image, answer_image));
		}
	}


	if (re.empty()) {
		throw ParserTriviaError(_("No questions in this file"));
	}

	if (re.max_level_cnt() == 0) {
		re.set_max_level_cnt(re.size());
	}

	return re;
}





} // end namespace quimeleon
