/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005, 2006  Aike Reyer <aike@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_TRIVIA_H
#define QUIMELEON_TRIVIA_H

#include <vector>

#include <glibmm/ustring.h>

#include "trivias.h"
#include "error.h"




namespace quimeleon {





class Configuration;
class Trivias;



struct answer_t
{
	Glib::ustring text;
	Glib::ustring image;
};




class Trivia
{
public:
	Trivia() throw();
	Trivia(const Glib::ustring& question,
	       const std::vector<answer_t>& answers,
	       const std::vector<Glib::ustring>::size_type& correct,
	       const Glib::ustring& question_audio = "",
	       const Glib::ustring& answer_audio = "",
	       const Glib::ustring& question_image = "",
	       const Glib::ustring& answer_image = "");

	static Trivias read_trivia_file(const char* filename,
		const Configuration& configuration);

	const Glib::ustring& question() const throw()
	{
		return _question;
	}
	const std::vector<answer_t>& answers() const throw() { return _answers; }
	std::vector<Glib::ustring>::size_type correct() const throw()
	{
		return _correct;
	}
	const Glib::ustring& question_audio() const throw()
	{
		return _question_audio;
	}
	const Glib::ustring& answer_audio() const throw()
	{
		return _answer_audio;
	}
	const Glib::ustring& question_image() const throw()
	{
		return _question_image;
	}
	const Glib::ustring& answer_image() const throw()
	{
		return _answer_image;
	}


private:
	Glib::ustring _question;
	std::vector<answer_t> _answers;
	std::vector<Glib::ustring>::size_type _correct;
	Glib::ustring _question_audio;
	Glib::ustring _answer_audio;
	Glib::ustring _question_image;
	Glib::ustring _answer_image;
};





} // end namespace quimeleon




#endif
