/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005, 2006  Aike Reyer <aike@users.sourceforge.net>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "ui_manager.h"

#include "gettext.h"




namespace quimeleon {





Glib::RefPtr<UIManager>
UIManager::create()
{
	return Glib::RefPtr<UIManager>(new UIManager);
}



UIManager::UIManager()
	: _action_group(Gtk::ActionGroup::create())
{

	_action_group->add(Gtk::Action::create("MenuFile", _8("_File")));
	_action_group->add(Gtk::Action::create("Open", Gtk::Stock::OPEN),
		sigc::mem_fun(*this, &UIManager::on_action_file_open));
	_action_group->add(Gtk::Action::create("Save", Gtk::Stock::SAVE),
		sigc::mem_fun(*this, &UIManager::on_action_file_save));
	_action_group->add(Gtk::Action::create("Quit", Gtk::Stock::QUIT),
		sigc::mem_fun(*this, &UIManager::on_action_file_quit));


	Glib::RefPtr<Gtk::Action> preferences_menu_action
		= Gtk::Action::create("MenuSettings", _8("_Preferences"));
	_action_group->add(preferences_menu_action);

	Glib::RefPtr<Gtk::Action> preferences_menuitem_action
		= Gtk::Action::create("Preferences", Gtk::Stock::PREFERENCES);
	_action_group->add(preferences_menuitem_action,
		sigc::mem_fun(*this, &UIManager::on_action_settings_preferences));


	_action_group->add(Gtk::Action::create("MenuHelp", _8("_Help")));

	_action_group->add(Gtk::Action::create("About", Gtk::Stock::ABOUT),
		sigc::mem_fun(*this, &UIManager::on_action_help_about));


	insert_action_group(_action_group);

	const Glib::ustring ui_info =
		"<ui>"
		"  <menubar name='MainMenu'>"
		"    <menu action='MenuFile'>"
		"      <menuitem action='Open'/>"
		"      <menuitem action='Save'/>"
		"      <separator/>"
		"      <menuitem action='Quit'/>"
		"    </menu>"
		"    <menu action='MenuSettings'>"
		"      <menuitem action='Preferences'/>"
		"    </menu>"
		"    <menu action='MenuHelp'>"
		"      <menuitem action='About'/>"
		"    </menu>"
		"  </menubar>"
		"  <toolbar name='ToolBar'>"
		"    <toolitem action='Open'/>"
		"    <toolitem action='Save'/>"
		"  </toolbar>"
		"</ui>";

	add_ui_from_string(ui_info);
}




} // end namespace quimeleon
