/*
 * Quimeleon - a themeable quiz engine
 * Copyright © 2005, 2006  Aike Reyer <aike@users.sourceforge.net>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef QUIMELEON_UI_MANAGER_H
#define QUIMELEON_UI_MANAGER_H

#include <gtkmm/uimanager.h>
#include <gtkmm/stock.h>




namespace quimeleon {





class UIManager : public Gtk::UIManager
{
public:
	UIManager();

	static Glib::RefPtr<UIManager> create();


	typedef sigc::signal<void> menu_selected_t;

	inline menu_selected_t& signal_file_open() { return _signal_file_open; }
	inline menu_selected_t& signal_file_save() { return _signal_file_save; }
	inline menu_selected_t& signal_file_quit() { return _signal_file_quit; }

	inline menu_selected_t& signal_settings_preferences()
	{
		return _signal_settings_preferences;
	}

	inline menu_selected_t& signal_help_about() { return _signal_help_about; }

protected:
	void on_action_file_open() { _signal_file_open.emit(); }
	void on_action_file_save() { _signal_file_save.emit(); }
	void on_action_file_quit() { _signal_file_quit.emit(); }
	void on_action_settings_preferences()
	{
		_signal_settings_preferences.emit();
	}
	void on_action_help_about() { _signal_help_about.emit(); }


private:
	Glib::RefPtr<Gtk::ActionGroup> _action_group;

	menu_selected_t _signal_file_open;
	menu_selected_t _signal_file_save;
	menu_selected_t _signal_file_quit;
	menu_selected_t _signal_settings_preferences;
	menu_selected_t _signal_help_about;
};





} // end namespace quimeleon




#endif
